==> v1.3.0.zip: opentelemetry-dotnet-instrumentation/docs/CONTRIBUTING.md <==
# Contributing

[![Slack](https://img.shields.io/badge/slack-@cncf/otel--dotnet--auto--instr-brightgreen.svg?logo=slack)](https://cloud-native.slack.com/archives/C01NR1YLSE7)

We'd love your help!

[The project board](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/projects/1)
shows the current work in progress.

Please join our weekly [SIG meeting](https://github.com/open-telemetry/community#special-interest-groups).
Meeting notes are available as a public [Google
doc](https://docs.google.com/document/d/1XedN2D8_PH4YLej-maT8sp4RKogfuhFpccRi3QpUcoI/edit?usp=sharing).

Get in touch on [Slack](https://cloud-native.slack.com/archives/C01NR1YLSE7).
If you are new, you can create a CNCF Slack account [here](http://slack.cncf.io/).

## Give feedback

We are always looking for your feedback.

You can do this by [submitting a GitHub issue](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/issues/new).

You may also prefer writing on [Slack](https://cloud-native.slack.com/archives/C01NR1YLSE7).

## Report a bug

Reporting bugs is an important contribution. Please make sure to include:

* Expected and actual behavior
* OpenTelemetry, OS, and .NET versions you are using
* If possible, steps to reproduce

## Request a feature

If you would like to work on something that is not listed as an issue
(e.g. a new feature or enhancement) please first read our [design.md](design.md)
to make sure your proposal aligns with the goals of the
project, then create an issue and describe your proposal.

## How to contribute

Please read the [contribution guide](https://github.com/open-telemetry/community/blob/main/CONTRIBUTING.md)
and the [code of conduct](https://github.com/open-telemetry/community/blob/main/code-of-conduct.md).
for general practices of the OpenTelemetry project.

Select a good issue from the links below (ordered by difficulty/complexity):

* [Good First Issue](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/issues?utf8=%E2%9C%93&q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22)
* [Help Wanted](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22)

Comment on the issue that you want to work on so we can assign it to you and
clarify anything related to it.

If you would like to work on something that is not listed as an issue,
please [request a feature](#request-a-feature) first.
It is best to do this in advance so that maintainers can decide if the proposal
is a good fit for this repository.
This will help avoid situations when you spend significant time
on something that maintainers may decide this repo is not the right place for.

See [developing.md](developing.md) to learn more about
the development environment setup and usage.

==> v1.4.0.zip: opentelemetry-dotnet-instrumentation/docs/CONTRIBUTING.md <==
# Contributing

[![Slack](https://img.shields.io/badge/slack-@cncf/otel--dotnet--auto--instr-brightgreen.svg?logo=slack)](https://cloud-native.slack.com/archives/C01NR1YLSE7)

We'd love your help!

[The project board](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/projects/1)
shows the current work in progress.

Please join our weekly [SIG meeting](https://github.com/open-telemetry/community#special-interest-groups).
Meeting notes are available as a public [Google
doc](https://docs.google.com/document/d/1dYdwRQVE3zu0vlp_lqGctNm0dCQUkDo2LfScUJzpuT8/edit?usp=sharing).

Get in touch on [Slack](https://cloud-native.slack.com/archives/C01NR1YLSE7).
If you are new, you can create a CNCF Slack account [here](http://slack.cncf.io/).

## Give feedback

We are always looking for your feedback.

You can do this by [submitting a GitHub issue](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/issues/new).

You may also prefer writing on [Slack](https://cloud-native.slack.com/archives/C01NR1YLSE7).

## Report a bug

Reporting bugs is an important contribution. Please make sure to include:

* Expected and actual behavior
* OpenTelemetry, OS, and .NET versions you are using
* If possible, steps to reproduce

## Request a feature

If you would like to work on something that is not listed as an issue
(e.g. a new feature or enhancement) please first read our [design.md](design.md)
to make sure your proposal aligns with the goals of the
project, then create an issue and describe your proposal.

## How to contribute

Please read the [contribution guide](https://github.com/open-telemetry/community/blob/main/CONTRIBUTING.md)
and the [code of conduct](https://github.com/open-telemetry/community/blob/main/code-of-conduct.md).
for general practices of the OpenTelemetry project.

Select a good issue from the links below (ordered by difficulty/complexity):

* [Good First Issue](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/issues?utf8=%E2%9C%93&q=is%3Aissue+is%3Aopen+label%3A%22good+first+issue%22)
* [Help Wanted](https://github.com/open-telemetry/opentelemetry-dotnet-instrumentation/issues?q=is%3Aissue+is%3Aopen+label%3A%22help+wanted%22)

Comment on the issue that you want to work on so we can assign it to you and
clarify anything related to it.

If you would like to work on something that is not listed as an issue,
please [request a feature](#request-a-feature) first.
It is best to do this in advance so that maintainers can decide if the proposal
is a good fit for this repository.
This will help avoid situations when you spend significant time
on something that maintainers may decide this repo is not the right place for.

See [developing.md](developing.md) to learn more about
the development environment setup and usage.
